@@ -1,4 +1,4 @@
 class Data:
     class Type:
         PORTFOLIO = 'portfolio'
-        CACHFUNDS = 'cashFunds'
\ No newline at end of file
+        CASHFUNDS = 'cashFunds'
\ No newline at end of file
